@@ -4,6 +4,14 @@ This is used to test ability to detect and use custom modules.
 """
 from ansible.module_utils.basic import AnsibleModule
 
+EXAMPLES = r"""
+- name: "playbook"
+  tasks:
+    - name: Hello
+      debug:
+        msg: 'world'
+"""
+
 
 def main() -> None:
     """Return the module instance."""
@@ -12,5 +20,5 @@ def main() -> None:
             "data": {"default": None},
             "path": {"default": None},
             "file": {"default": None},
-        }
+        },
     )
