@@ -36,6 +36,17 @@ from ansible_compat.prerun import get_cache_dir
 from filelock import FileLock, Timeout
 from rich.markup import escape
 
+from ansiblelint.constants import RC, SKIP_SCHEMA_UPDATE
+
+# safety check for broken ansible core, needs to happen first
+try:
+    # pylint: disable=unused-import
+    from ansible.parsing.dataloader import DataLoader  # noqa: F401
+
+except Exception as _exc:  # pylint: disable=broad-exception-caught # noqa: BLE001
+    logging.fatal(_exc)
+    sys.exit(RC.INVALID_CONFIG)
+# pylint: disable=ungrouped-imports
 from ansiblelint import cli
 from ansiblelint._mockings import _perform_mockings_cleanup
 from ansiblelint.app import get_app
@@ -53,8 +64,8 @@ from ansiblelint.config import (
     log_entries,
     options,
 )
-from ansiblelint.constants import RC
 from ansiblelint.loaders import load_ignore_txt
+from ansiblelint.runner import get_matches
 from ansiblelint.skip_utils import normalize_tag
 from ansiblelint.version import __version__
 
@@ -202,11 +213,79 @@ def support_banner() -> None:
         )
 
 
-# pylint: disable=too-many-statements,too-many-locals
+def fix(runtime_options: Options, result: LintResult, rules: RulesCollection) -> None:
+    """Fix the linting errors.
+
+    :param options: Options object
+    :param result: LintResult object
+    """
+    match_count = len(result.matches)
+    _logger.debug("Begin fixing: %s matches", match_count)
+    ruamel_safe_version = "0.17.26"
+
+    # pylint: disable=import-outside-toplevel
+    from packaging.version import Version
+    from ruamel.yaml import __version__ as ruamel_yaml_version_str
+
+    # pylint: enable=import-outside-toplevel
+
+    if Version(ruamel_safe_version) > Version(ruamel_yaml_version_str):
+        _logger.warning(
+            "We detected use of `--fix` feature with a buggy ruamel-yaml %s library instead of >=%s, upgrade it before reporting any bugs like dropped comments.",
+            ruamel_yaml_version_str,
+            ruamel_safe_version,
+        )
+    acceptable_tags = {"all", "none", *rules.known_tags()}
+    unknown_tags = set(options.write_list).difference(acceptable_tags)
+
+    if unknown_tags:
+        _logger.error(
+            "Found invalid value(s) (%s) for --fix arguments, must be one of: %s",
+            ", ".join(unknown_tags),
+            ", ".join(acceptable_tags),
+        )
+        sys.exit(RC.INVALID_CONFIG)
+    _do_transform(result, options)
+
+    rerun = ["yaml"]
+    resolved = []
+    for idx, match in reversed(list(enumerate(result.matches))):
+        _logger.debug("Fixing: (%s of %s) %s", match_count - idx, match_count, match)
+        if match.fixed:
+            _logger.debug("Fixed, removed: %s", match)
+            result.matches.pop(idx)
+            continue
+        if match.rule.id not in rerun:
+            _logger.debug("Not rerun eligible: %s", match)
+            continue
+
+        uid = (match.rule.id, match.filename)
+        if uid in resolved:
+            _logger.debug("Previously resolved: %s", match)
+            result.matches.pop(idx)
+            continue
+        _logger.debug("Rerunning: %s", match)
+        runtime_options.tags = [match.rule.id]
+        runtime_options.lintables = [match.filename]
+        runtime_options._skip_ansible_syntax_check = True  # noqa: SLF001
+        new_results = get_matches(rules, runtime_options)
+        if not new_results.matches:
+            _logger.debug("Newly resolved: %s", match)
+            result.matches.pop(idx)
+            resolved.append(uid)
+            continue
+        if match in new_results.matches:
+            _logger.debug("Still found: %s", match)
+            continue
+        _logger.debug("Fixed, removed: %s", match)
+        result.matches.pop(idx)
+
+
+# pylint: disable=too-many-locals
 def main(argv: list[str] | None = None) -> int:
     """Linter CLI entry point."""
     # alter PATH if needed (venv support)
-    path_inject()
+    path_inject(argv[0] if argv and argv[0] else "")
 
     if argv is None:  # pragma: no cover
         argv = sys.argv
@@ -236,7 +315,23 @@ def main(argv: list[str] | None = None) -> int:
     _logger.debug("Options: %s", options)
     _logger.debug("CWD: %s", Path.cwd())
 
-    if not options.offline:
+    # checks if we have `ANSIBLE_LINT_SKIP_SCHEMA_UPDATE` set to bypass schema
+    # update. Also skip if in offline mode.
+    # env var set to skip schema refresh
+    skip_schema_update = (
+        bool(
+            int(
+                os.environ.get(
+                    SKIP_SCHEMA_UPDATE,
+                    "0",
+                ),
+            ),
+        )
+        or options.offline
+        or options.nodeps
+    )
+
+    if not skip_schema_update:
         # pylint: disable=import-outside-toplevel
         from ansiblelint.schemas.__main__ import refresh_schemas
 
@@ -244,7 +339,6 @@ def main(argv: list[str] | None = None) -> int:
 
     # pylint: disable=import-outside-toplevel
     from ansiblelint.rules import RulesCollection
-    from ansiblelint.runner import _get_matches
 
     if options.list_profiles:
         from ansiblelint.generate_docs import profiles_as_rich
@@ -265,30 +359,7 @@ def main(argv: list[str] | None = None) -> int:
 
     if isinstance(options.tags, str):
         options.tags = options.tags.split(",")  # pragma: no cover
-    result = _get_matches(rules, options)
-
-    if options.write_list:
-        ruamel_safe_version = "0.17.26"
-        from packaging.version import Version
-        from ruamel.yaml import __version__ as ruamel_yaml_version_str
-
-        if Version(ruamel_safe_version) > Version(ruamel_yaml_version_str):
-            _logger.warning(
-                "We detected use of `--fix` feature with a buggy ruamel-yaml %s library instead of >=%s, upgrade it before reporting any bugs like dropped comments.",
-                ruamel_yaml_version_str,
-                ruamel_safe_version,
-            )
-        acceptable_tags = {"all", "none", *rules.known_tags()}
-        unknown_tags = set(options.write_list).difference(acceptable_tags)
-
-        if unknown_tags:
-            _logger.error(
-                "Found invalid value(s) (%s) for --fix arguments, must be one of: %s",
-                ", ".join(unknown_tags),
-                ", ".join(acceptable_tags),
-            )
-            sys.exit(RC.INVALID_CONFIG)
-        _do_transform(result, options)
+    result = get_matches(rules, options)
 
     mark_as_success = True
 
@@ -302,6 +373,10 @@ def main(argv: list[str] | None = None) -> int:
     for match in result.matches:
         if match.tag in ignore_map[match.filename]:
             match.ignored = True
+            _logger.debug("Ignored: %s", match)
+
+    if options.write_list:
+        fix(runtime_options=options, result=result, rules=rules)
 
     app.render_matches(result.matches)
 
@@ -335,7 +410,7 @@ def _run_cli_entrypoint() -> None:
         raise SystemExit(exc) from exc
 
 
-def path_inject() -> None:
+def path_inject(own_location: str = "") -> None:
     """Add python interpreter path to top of PATH to fix outside venv calling."""
     # This make it possible to call ansible-lint that was installed inside a
     # virtualenv without having to pre-activate it. Otherwise subprocess will
@@ -376,6 +451,14 @@ def path_inject() -> None:
     ):
         inject_paths.append(str(py_path))
 
+    # last option, if nothing else is found, just look next to ourselves...
+    if (
+        own_location
+        and (Path(own_location).parent / "ansible").exists()
+        and str(Path(own_location).parent) not in paths
+    ):
+        inject_paths.append(str(Path(own_location).parent))
+
     if not os.environ.get("PYENV_VIRTUAL_ENV", None):
         if inject_paths:
             print(  # noqa: T201
