@@ -1,6 +1,7 @@
 """Application."""
 from __future__ import annotations
 
+import copy
 import itertools
 import logging
 import os
@@ -102,7 +103,11 @@ class App:
         if self.options.sarif_file:
             sarif = formatters.SarifFormatter(self.options.cwd, True)
             json = sarif.format_result(matches)
-            with self.options.sarif_file.open("w", encoding="utf-8") as sarif_file:
+            with Path.open(
+                self.options.sarif_file,
+                "w",
+                encoding="utf-8",
+            ) as sarif_file:
                 sarif_file.write(json)
 
     def count_results(self, matches: list[MatchError]) -> SummarizedResults:
@@ -218,7 +223,7 @@ class App:
 
         if self.options.write_list and "yaml" in self.options.skip_list:
             _logger.warning(
-                "You specified '--write', but no files can be modified "
+                "You specified '--fix', but no files can be modified "
                 "because 'yaml' is in 'skip_list'.",
             )
 
@@ -245,7 +250,7 @@ class App:
             return RC.SUCCESS
         return RC.VIOLATIONS_FOUND
 
-    def report_summary(  # pylint: disable=too-many-locals
+    def report_summary(  # pylint: disable=too-many-locals # noqa: C901
         self,
         summary: SummarizedResults,
         changed_files_count: int,
@@ -311,26 +316,34 @@ class App:
             # rate stars for the top 5 profiles (min would not get
             rating = 5 - (len(PROFILES.keys()) - passed_profile_count)
             if 0 < rating < 6:
-                stars = f", {rating}/5 star rating"
+                stars = f" Rating: {rating}/5 star"
 
             console_stderr.print(table)
             console_stderr.print()
 
-        if is_success:
-            msg = "[green]Passed[/] with "
-        else:
-            msg = "[red][bold]Failed[/][/] after "
-
-        if summary.passed_profile:
-            msg += f"[bold]{summary.passed_profile}[/] profile"
-        if stars:
-            msg += stars
+        msg = "[green]Passed[/]" if is_success else "[red][bold]Failed[/][/]"
 
         msg += f": {summary.failures} failure(s), {summary.warnings} warning(s)"
         if summary.fixed:
             msg += f", and fixed {summary.fixed} issue(s)"
         msg += f" on {files_count} files."
 
+        # Now we add some information about required and passed profile
+        if self.options.profile:
+            msg += f" Profile '{self.options.profile}' was required"
+            if summary.passed_profile:
+                if summary.passed_profile == self.options.profile:
+                    msg += ", and it passed."
+                else:
+                    msg += f", but '{summary.passed_profile}' profile passed."
+            else:
+                msg += "."
+        elif summary.passed_profile:
+            msg += f" Last profile that met the validation criteria was '{summary.passed_profile}'."
+
+        if stars:
+            msg += stars
+
         # on offline mode and when run under pre-commit we do not want to
         # check for updates.
         if not self.options.offline and os.environ.get("PRE_COMMIT", "0") != "1":
@@ -368,12 +381,20 @@ def _sanitize_list_options(tag_list: list[str]) -> list[str]:
 
 
 @lru_cache
-def get_app() -> App:
+def get_app(*, offline: bool | None = None) -> App:
     """Return the application instance, caching the return value."""
-    offline = default_options.offline
-    app = App(options=default_options)
+    if offline is None:
+        offline = default_options.offline
+
+    if default_options.offline != offline:
+        options = copy.deepcopy(default_options)
+        options.offline = offline
+    else:
+        options = default_options
+
+    app = App(options=options)
     # Make linter use the cache dir from compat
-    default_options.cache_dir = app.runtime.cache_dir
+    options.cache_dir = app.runtime.cache_dir
 
     role_name_check = 0
     if "role-name" in app.options.warn_list:
@@ -383,7 +404,7 @@ def get_app() -> App:
 
     # mocking must happen before prepare_environment or galaxy install might
     # fail.
-    _perform_mockings()
+    _perform_mockings(options=app.options)
     app.runtime.prepare_environment(
         install_local=(not offline),
         offline=offline,
