@@ -23,10 +23,12 @@ import pathlib
 from ansiblelint.errors import MatchError
 from ansiblelint.file_utils import Lintable
 from ansiblelint.formatters import Formatter
-from ansiblelint.rules import AnsibleLintRule
+from ansiblelint.rules import AnsibleLintRule, RulesCollection
 
+collection = RulesCollection()
 rule = AnsibleLintRule()
 rule.id = "TCF0001"
+collection.register(rule)
 formatter = Formatter(pathlib.Path.cwd(), display_relative_path=True)
 # These details would generate a rich rendering error if not escaped:
 DETAILS = "Some [/tmp/foo] details."
@@ -36,33 +38,33 @@ def test_format_coloured_string() -> None:
     """Test formetting colored."""
     match = MatchError(
         message="message",
-        linenumber=1,
+        lineno=1,
         details=DETAILS,
-        filename=Lintable("filename.yml"),
+        lintable=Lintable("filename.yml", content=""),
         rule=rule,
     )
-    formatter.format(match)
+    formatter.apply(match)
 
 
 def test_unicode_format_string() -> None:
     """Test formatting unicode."""
     match = MatchError(
         message="\U0001f427",
-        linenumber=1,
+        lineno=1,
         details=DETAILS,
-        filename=Lintable("filename.yml"),
+        lintable=Lintable("filename.yml", content=""),
         rule=rule,
     )
-    formatter.format(match)
+    formatter.apply(match)
 
 
 def test_dict_format_line() -> None:
     """Test formatting dictionary details."""
     match = MatchError(
         message="xyz",
-        linenumber=1,
-        details={"hello": "world"},  # type: ignore
-        filename=Lintable("filename.yml"),
+        lineno=1,
+        details={"hello": "world"},  # type: ignore[arg-type]
+        lintable=Lintable("filename.yml", content=""),
         rule=rule,
     )
-    formatter.format(match)
+    formatter.apply(match)
