@@ -1,14 +1,17 @@
 """Tests for Transformer."""
 from __future__ import annotations
 
+import os
 import shutil
 from pathlib import Path
 from typing import TYPE_CHECKING
+from unittest import mock
 
 import pytest
 
 import ansiblelint.__main__ as main
 from ansiblelint.app import App
+from ansiblelint.file_utils import Lintable
 
 # noinspection PyProtectedMember
 from ansiblelint.runner import LintResult, get_matches
@@ -23,122 +26,167 @@ if TYPE_CHECKING:
 def fixture_runner_result(
     config_options: Options,
     default_rules_collection: RulesCollection,
-    playbook: str,
+    playbook_str: str,
 ) -> LintResult:
     """Fixture that runs the Runner to populate a LintResult for a given file."""
-    config_options.lintables = [playbook]
+    config_options.lintables = [playbook_str]
     result = get_matches(rules=default_rules_collection, options=config_options)
     return result
 
 
 @pytest.mark.parametrize(
-    ("playbook", "matches_count", "transformed"),
+    ("playbook_str", "matches_count", "transformed", "is_owned_by_ansible"),
     (
         # reuse TestRunner::test_runner test cases to ensure transformer does not mangle matches
         pytest.param(
             "examples/playbooks/nomatchestest.yml",
             0,
             False,
+            True,
             id="nomatchestest",
         ),
-        pytest.param("examples/playbooks/unicode.yml", 1, False, id="unicode"),
+        pytest.param("examples/playbooks/unicode.yml", 1, False, True, id="unicode"),
         pytest.param(
             "examples/playbooks/lots_of_warnings.yml",
             993,
             False,
+            True,
             id="lots_of_warnings",
         ),
-        pytest.param("examples/playbooks/become.yml", 0, False, id="become"),
+        pytest.param("examples/playbooks/become.yml", 0, False, True, id="become"),
         pytest.param(
             "examples/playbooks/contains_secrets.yml",
             0,
             False,
+            True,
             id="contains_secrets",
         ),
         pytest.param(
             "examples/playbooks/vars/empty_vars.yml",
             0,
             False,
+            True,
             id="empty_vars",
         ),
-        pytest.param("examples/playbooks/vars/strings.yml", 0, True, id="strings"),
-        pytest.param("examples/playbooks/vars/empty.yml", 1, False, id="empty"),
-        pytest.param("examples/playbooks/name-case.yml", 1, True, id="name_case"),
-        pytest.param("examples/playbooks/fqcn.yml", 3, True, id="fqcn"),
+        pytest.param(
+            "examples/playbooks/vars/strings.yml",
+            0,
+            True,
+            True,
+            id="strings",
+        ),
+        pytest.param("examples/playbooks/vars/empty.yml", 1, False, True, id="empty"),
+        pytest.param("examples/playbooks/name-case.yml", 1, True, True, id="name_case"),
+        pytest.param("examples/playbooks/fqcn.yml", 3, True, True, id="fqcn"),
         pytest.param(
             "examples/playbooks/multi_yaml_doc.yml",
             1,
             False,
+            True,
             id="multi_yaml_doc",
         ),
         pytest.param(
             "examples/playbooks/transform_command_instead_of_shell.yml",
             3,
             True,
+            True,
             id="cmd_instead_of_shell",
         ),
         pytest.param(
             "examples/playbooks/transform-deprecated-local-action.yml",
             1,
             True,
+            True,
             id="dep_local_action",
         ),
         pytest.param(
             "examples/playbooks/transform-block-indentation-indicator.yml",
             0,
             True,
+            True,
             id="multiline_msg_with_indent_indicator",
         ),
         pytest.param(
             "examples/playbooks/transform-jinja.yml",
             7,
             True,
+            True,
             id="jinja_spacing",
         ),
         pytest.param(
             "examples/playbooks/transform-no-jinja-when.yml",
             3,
             True,
+            True,
             id="no_jinja_when",
         ),
         pytest.param(
             "examples/playbooks/vars/transform_nested_data.yml",
             3,
             True,
+            True,
             id="nested",
         ),
         pytest.param(
             "examples/playbooks/transform-key-order.yml",
             6,
             True,
+            True,
             id="key_order_transform",
         ),
         pytest.param(
             "examples/playbooks/transform-no-free-form.yml",
             2,
             True,
+            True,
             id="no_free_form_transform",
         ),
         pytest.param(
             "examples/playbooks/transform-partial-become.yml",
             4,
             True,
+            True,
             id="partial_become",
         ),
+        pytest.param(
+            "examples/playbooks/transform-key-order-play.yml",
+            1,
+            True,
+            True,
+            id="key_order_play_transform",
+        ),
+        pytest.param(
+            "examples/.github/workflows/sample.yml",
+            0,
+            False,
+            False,
+            id="github-workflow",
+        ),
+        pytest.param(
+            "examples/playbooks/invalid-transform.yml",
+            1,
+            False,
+            True,
+            id="invalid_transform",
+        ),
     ),
 )
-def test_transformer(  # pylint: disable=too-many-arguments, too-many-locals
+@mock.patch.dict(os.environ, {"ANSIBLE_LINT_WRITE_TMP": "1"}, clear=True)
+def test_transformer(  # pylint: disable=too-many-arguments
     config_options: Options,
-    copy_examples_dir: tuple[Path, Path],
-    playbook: str,
+    playbook_str: str,
     runner_result: LintResult,
     transformed: bool,
+    is_owned_by_ansible: bool,
     matches_count: int,
 ) -> None:
     """Test that transformer can go through any corner cases.
 
     Based on TestRunner::test_runner
     """
+    # test ability to detect is_owned_by_ansible
+    assert Lintable(playbook_str).is_owned_by_ansible() == is_owned_by_ansible
+    playbook = Path(playbook_str)
     config_options.write_list = ["all"]
     transformer = Transformer(result=runner_result, options=config_options)
     transformer.run()
@@ -146,21 +194,18 @@ def test_transformer(  # pylint: disable=too-many-arguments, too-many-locals
     matches = runner_result.matches
     assert len(matches) == matches_count
 
-    orig_dir, tmp_dir = copy_examples_dir
-    orig_playbook = orig_dir / playbook
-    expected_playbook = orig_dir / playbook.replace(".yml", ".transformed.yml")
-    transformed_playbook = tmp_dir / playbook
-
-    orig_playbook_content = orig_playbook.read_text()
-    expected_playbook_content = expected_playbook.read_text()
-    transformed_playbook_content = transformed_playbook.read_text()
-
+    orig_content = playbook.read_text(encoding="utf-8")
     if transformed:
-        assert orig_playbook_content != transformed_playbook_content
-    else:
-        assert orig_playbook_content == transformed_playbook_content
+        expected_content = playbook.with_suffix(
+            f".transformed{playbook.suffix}",
+        ).read_text(encoding="utf-8")
+        transformed_content = playbook.with_suffix(f".tmp{playbook.suffix}").read_text(
+            encoding="utf-8",
+        )
 
-    assert transformed_playbook_content == expected_playbook_content
+        assert orig_content != transformed_content
+        assert expected_content == transformed_content
+        playbook.with_suffix(f".tmp{playbook.suffix}").unlink()
 
 
 @pytest.mark.parametrize(
